import {Component, OnInit} from '@angular/core';
import {InputOutputComponent} from "../input-output/input-output.component";
import {JsonTransformService} from "../json-transform.service";

@Component({
  selector: 'app-json2csharp',
  standalone: true,
  imports: [
    InputOutputComponent
  ],
  templateUrl: './json2-csharp.component.html',
  styleUrl: './json2-csharp.component.scss'
})
export class Json2CsharpComponent implements OnInit {
  input: string = JSON.stringify({first_name: "John", last_name: "Doe"}, null, 2);
  inputOptions = {theme: 'vs-dark', language: 'json', readOnly: false};
  output: string = JSON.stringify({first_name: "John", last_name: "Doe"});
  outputOptions = {theme: 'vs-dark', language: 'csharp', readOnly: true};

  constructor(private service: JsonTransformService) {
  }

  ngOnInit(): void {
    this.service
      .json2csharp(this.input)
      .subscribe(response => {
        console.log(response);

        if (response.status === 200) {
          this.output = response.body.result;
        } else if (response.status === 499) {
          this.output = response.body.detail;
        }
      });
  }

  handleInputChange($event: any) {
    console.log($event);
    this.service
      .json2csharp($event)
      .subscribe({
        next: response => {
          console.log(response);
          this.output = response.body.result;
        },
        error: response => {
          console.log(response)
          if (response.status === 499) {
            this.output = response.error.detail;
            console.log(response.error.detail);
          }
        }
      });
  }
}
