import {Component} from '@angular/core';
import {EditorComponent} from "ngx-monaco-editor-v2";
import {FormsModule} from "@angular/forms";
import {InputOutputComponent} from "../input-output/input-output.component";
import {JsonTransformService} from "../json-transform.service";

@Component({
  selector: 'app-prettify',
  standalone: true,
  imports: [
    EditorComponent,
    FormsModule,
    InputOutputComponent
  ],
  templateUrl: './prettify.component.html',
  styleUrl: './prettify.component.scss'
})
export class PrettifyComponent {
  input: string = JSON.stringify({first_name: "John", last_name: "Doe"});
  inputOptions = {theme: 'vs-dark', language: 'json', readOnly: false};
  output: string = JSON.stringify({first_name: "John", last_name: "Doe"}, null, 2);
  outputOptions = {theme: 'vs-dark', language: 'json', readOnly: true};
  error: string = "";

  constructor(private service: JsonTransformService) {
  }

  handleInputChange($event: any) {
    console.log($event);
    this.service
      .prettify($event)
      .subscribe({
        next: response => {
          console.log(response);
          this.output = response.body.result;
        },
        error: response => {
          console.log(response)
          if (response.status === 499) {
            this.output = response.error.detail;
            console.log(response.error.detail);
          }
        }
      });
  }
}
